==> AsposeCellsCloud-CellsApi-25.9.tar.gz: AsposeCellsCloud-CellsApi-25.9/docs/model/OleObject.md <==
# AsposeCellsCloud::Object::OleObject 

## Load the model package
```perl
use AsposeCellsCloud::Object::OleObject;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**DisplayAsIcon** | **boolean** | True if the specified object is displayed as an icon                         and the image will not be auto changed. |
**FileFormatType** | **string** | Gets and sets the file type of the embedded ole object data |
**ImageSourceFullName** | **string** | Gets or sets the path and name of the source file for the linked image. |
**IsAutoSize** | **boolean** | True indicates that the size of the ole object will be auto changed as the size of snapshot of the embedded content                        when the ole object is activated. |
**IsLink** | **boolean** | Returns true if the OleObject links to the file. |
**ProgID** | **string** | Gets or sets the ProgID of the OLE object. |
**SourceFullName** | **string** | Returns the source full name of the source file for the linked OLE object. |
**Name** | **string** |  |
**MsoDrawingType** | **string** |  |
**AutoShapeType** | **string** |  |
**Placement** | **string** |  |
**UpperLeftRow** | **int** |  |
**Top** | **int** |  |
**UpperLeftColumn** | **int** |  |
**Left** | **int** |  |
**LowerRightRow** | **int** |  |
**Bottom** | **int** |  |
**LowerRightColumn** | **int** |  |
**Right** | **int** |  |
**Width** | **int** |  |
**Height** | **int** |  |
**X** | **int** |  |
**Y** | **int** |  |
**RotationAngle** | **double** |  |
**HtmlText** | **string** |  |
**Text** | **string** |  |
**AlternativeText** | **string** |  |
**TextHorizontalAlignment** | **string** |  |
**TextHorizontalOverflow** | **string** |  |
**TextOrientationType** | **string** |  |
**TextVerticalAlignment** | **string** |  |
**TextVerticalOverflow** | **string** |  |
**IsGroup** | **boolean** |  |
**IsHidden** | **boolean** |  |
**IsLockAspectRatio** | **boolean** |  |
**IsLocked** | **boolean** |  |
**IsPrintable** | **boolean** |  |
**IsTextWrapped** | **boolean** |  |
**IsWordArt** | **boolean** |  |
**LinkedCell** | **string** |  |
**ZOrderPosition** | **int** |  |
**Font** | **Font** |  |
**Hyperlink** | **string** |  |
**link** | **Link** |  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> AsposeCellsCloud-CellsApi-26.2.tar.gz: AsposeCellsCloud-CellsApi-26.2/docs/model/OleObject.md <==
# AsposeCellsCloud::Object::OleObject 

## Load the model package
```perl
use AsposeCellsCloud::Object::OleObject;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**DisplayAsIcon** | **boolean** | True if the specified object is displayed as an icon                         and the image will not be auto changed. |
**FileFormatType** | **string** | Gets and sets the file type of the embedded ole object data |
**ImageSourceFullName** | **string** | Gets or sets the path and name of the source file for the linked image. |
**IsAutoSize** | **boolean** | True indicates that the size of the ole object will be auto changed as the size of snapshot of the embedded content                        when the ole object is activated. |
**IsLink** | **boolean** | Returns true if the OleObject links to the file. |
**ProgID** | **string** | Gets or sets the ProgID of the OLE object. |
**SourceFullName** | **string** | Returns the source full name of the source file for the linked OLE object. |
**Name** | **string** |  |
**MsoDrawingType** | **string** |  |
**AutoShapeType** | **string** |  |
**Placement** | **string** |  |
**UpperLeftRow** | **int** |  |
**Top** | **int** |  |
**UpperLeftColumn** | **int** |  |
**Left** | **int** |  |
**LowerRightRow** | **int** |  |
**Bottom** | **int** |  |
**LowerRightColumn** | **int** |  |
**Right** | **int** |  |
**Width** | **int** |  |
**Height** | **int** |  |
**X** | **int** |  |
**Y** | **int** |  |
**RotationAngle** | **double** |  |
**HtmlText** | **string** |  |
**Text** | **string** |  |
**AlternativeText** | **string** |  |
**TextHorizontalAlignment** | **string** |  |
**TextHorizontalOverflow** | **string** |  |
**TextOrientationType** | **string** |  |
**TextVerticalAlignment** | **string** |  |
**TextVerticalOverflow** | **string** |  |
**IsGroup** | **boolean** |  |
**IsHidden** | **boolean** |  |
**IsLockAspectRatio** | **boolean** |  |
**IsLocked** | **boolean** |  |
**IsPrintable** | **boolean** |  |
**IsTextWrapped** | **boolean** |  |
**IsWordArt** | **boolean** |  |
**LinkedCell** | **string** |  |
**ZOrderPosition** | **int** |  |
**Font** | **Font** |  |
**Hyperlink** | **string** |  |
**link** | **Link** |  |  


[[Back to Model list]](../DeveloperGuide.md#model-reference)  
[[Back to README]](../../README.md)
